Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase')
-rw-r--r--plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/QVTbase.xtextbinbin21972 -> 21972 bytes
-rw-r--r--plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/QVTbaseGrammarResource.java4
-rw-r--r--plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/parser/antlr/internal/InternalQVTbase.g16
-rw-r--r--plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/parser/antlr/internal/InternalQVTbaseParser.java46
-rw-r--r--plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/services/QVTbaseGrammarAccess.java2
5 files changed, 34 insertions, 34 deletions
diff --git a/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/QVTbase.xtextbin b/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/QVTbase.xtextbin
index 9eda2ed69..fbf73fd98 100644
--- a/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/QVTbase.xtextbin
+++ b/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/QVTbase.xtextbin
Binary files differ
diff --git a/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/QVTbaseGrammarResource.java b/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/QVTbaseGrammarResource.java
index 2255af3fd..c680dcdf4 100644
--- a/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/QVTbaseGrammarResource.java
+++ b/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/QVTbaseGrammarResource.java
@@ -810,9 +810,9 @@ public class QVTbaseGrammarResource extends AbstractGrammarResource
createKeyword("}")));
PR_MapLiteralPartCS.setAlternatives(
createGroup(
- createAssignment("ownedKey", "=", createRuleCall(PR_ExpCS)),
+ createAssignment("ownedValue", "=", createRuleCall(PR_ExpCS)),
createKeyword("<-"),
- createAssignment("ownedValue", "=", createRuleCall(PR_ExpCS))));
+ createAssignment("ownedKey", "=", createRuleCall(PR_ExpCS))));
PR_MapTypeCS.setAlternatives(
createGroup(
createAssignment("name", "=", createKeyword("Map")),
diff --git a/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/parser/antlr/internal/InternalQVTbase.g b/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/parser/antlr/internal/InternalQVTbase.g
index a4ab1eafb..9fc01dde0 100644
--- a/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/parser/antlr/internal/InternalQVTbase.g
+++ b/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/parser/antlr/internal/InternalQVTbase.g
@@ -4459,16 +4459,16 @@ ruleMapLiteralPartCS returns [EObject current=null]
((
(
{
- newCompositeNode(grammarAccess.getMapLiteralPartCSAccess().getOwnedKeyExpCSParserRuleCall_0_0());
+ newCompositeNode(grammarAccess.getMapLiteralPartCSAccess().getOwnedValueExpCSParserRuleCall_0_0());
}
- lv_ownedKey_0_0=ruleExpCS {
+ lv_ownedValue_0_0=ruleExpCS {
if ($current==null) {
$current = createModelElementForParent(grammarAccess.getMapLiteralPartCSRule());
}
set(
$current,
- "ownedKey",
- lv_ownedKey_0_0,
+ "ownedValue",
+ lv_ownedValue_0_0,
"org.eclipse.ocl.xtext.essentialocl.EssentialOCL.ExpCS");
afterParserOrEnumRuleCall();
}
@@ -4481,16 +4481,16 @@ ruleMapLiteralPartCS returns [EObject current=null]
(
(
{
- newCompositeNode(grammarAccess.getMapLiteralPartCSAccess().getOwnedValueExpCSParserRuleCall_2_0());
+ newCompositeNode(grammarAccess.getMapLiteralPartCSAccess().getOwnedKeyExpCSParserRuleCall_2_0());
}
- lv_ownedValue_2_0=ruleExpCS {
+ lv_ownedKey_2_0=ruleExpCS {
if ($current==null) {
$current = createModelElementForParent(grammarAccess.getMapLiteralPartCSRule());
}
set(
$current,
- "ownedValue",
- lv_ownedValue_2_0,
+ "ownedKey",
+ lv_ownedKey_2_0,
"org.eclipse.ocl.xtext.essentialocl.EssentialOCL.ExpCS");
afterParserOrEnumRuleCall();
}
diff --git a/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/services/QVTbaseGrammarAccess.java b/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/services/QVTbaseGrammarAccess.java
index 52bd8c739..3d09af944 100644
--- a/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/services/QVTbaseGrammarAccess.java
+++ b/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/services/QVTbaseGrammarAccess.java
@@ -2941,7 +2941,7 @@ public class QVTbaseGrammarAccess extends AbstractGrammarElementFinder {
}
//MapLiteralPartCS:
- // ownedKey=ExpCS '<-' ownedValue=ExpCS;
+ // ownedValue=ExpCS '<-' ownedKey=ExpCS;
public EssentialOCLGrammarAccess.MapLiteralPartCSElements getMapLiteralPartCSAccess() {
return gaEssentialOCL.getMapLiteralPartCSAccess();
}

Back to the top
diff --git a/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/parser/antlr/internal/InternalQVTbaseParser.java b/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/parser/antlr/internal/InternalQVTbaseParser.java
index 81ec46c90..a63359b34 100644
--- a/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/parser/antlr/internal/InternalQVTbaseParser.java
+++ b/plugins/org.eclipse.qvtd.xtext.qvtbase/src-gen/org/eclipse/qvtd/xtext/qvtbase/parser/antlr/internal/InternalQVTbaseParser.java
@@ -13386,38 +13386,38 @@ public class InternalQVTbaseParser extends AbstractInternalAntlrParser {
// $ANTLR start "ruleMapLiteralPartCS"
- // InternalQVTbase.g:4455:1: ruleMapLiteralPartCS returns [EObject current=null] : ( ( (lv_ownedKey_0_0= ruleExpCS ) ) otherlv_1= '<-' ( (lv_ownedValue_2_0= ruleExpCS ) ) ) ;
+ // InternalQVTbase.g:4455:1: ruleMapLiteralPartCS returns [EObject current=null] : ( ( (lv_ownedValue_0_0= ruleExpCS ) ) otherlv_1= '<-' ( (lv_ownedKey_2_0= ruleExpCS ) ) ) ;
public final EObject ruleMapLiteralPartCS() throws RecognitionException {
EObject current = null;
Token otherlv_1=null;
- EObject lv_ownedKey_0_0 = null;
+ EObject lv_ownedValue_0_0 = null;
- EObject lv_ownedValue_2_0 = null;
+ EObject lv_ownedKey_2_0 = null;
enterRule();
try {
// InternalQVTbase.g:4458:28: ( ( ( (lv_ownedKey_0_0= ruleExpCS ) ) otherlv_1= '<-' ( (lv_ownedValue_2_0= ruleExpCS ) ) ) )
// InternalQVTbase.g:4459:1: ( ( (lv_ownedKey_0_0= ruleExpCS ) ) otherlv_1= '<-' ( (lv_ownedValue_2_0= ruleExpCS ) ) )
{
// InternalQVTbase.g:4459:1: ( ( (lv_ownedKey_0_0= ruleExpCS ) ) otherlv_1= '<-' ( (lv_ownedValue_2_0= ruleExpCS ) ) )
// InternalQVTbase.g:4459:2: ( (lv_ownedKey_0_0= ruleExpCS ) ) otherlv_1= '<-' ( (lv_ownedValue_2_0= ruleExpCS ) )
{
// InternalQVTbase.g:4459:2: ( (lv_ownedKey_0_0= ruleExpCS ) )
// InternalQVTbase.g:4460:1: (lv_ownedKey_0_0= ruleExpCS )
{
// InternalQVTbase.g:4460:1: (lv_ownedKey_0_0= ruleExpCS )
// InternalQVTbase.g:4461:3: lv_ownedKey_0_0= ruleExpCS
{
if ( state.backtracking==0 ) {
- newCompositeNode(grammarAccess.getMapLiteralPartCSAccess().getOwnedKeyExpCSParserRuleCall_0_0());
+ newCompositeNode(grammarAccess.getMapLiteralPartCSAccess().getOwnedValueExpCSParserRuleCall_0_0());
}
pushFollow(FollowSets000.FOLLOW_79);
- lv_ownedKey_0_0=ruleExpCS();
+ lv_ownedValue_0_0=ruleExpCS();
state._fsp--;
if (state.failed) return current;
@@ -13428,8 +13428,8 @@ public class InternalQVTbaseParser extends AbstractInternalAntlrParser {
}
set(
current,
- "ownedKey",
- lv_ownedKey_0_0,
+ "ownedValue",
+ lv_ownedValue_0_0,
"org.eclipse.ocl.xtext.essentialocl.EssentialOCL.ExpCS");
afterParserOrEnumRuleCall();
@@ -13446,19 +13446,19 @@ public class InternalQVTbaseParser extends AbstractInternalAntlrParser {
newLeafNode(otherlv_1, grammarAccess.getMapLiteralPartCSAccess().getLessThanSignHyphenMinusKeyword_1());
}
// InternalQVTbase.g:4481:1: ( (lv_ownedValue_2_0= ruleExpCS ) )
// InternalQVTbase.g:4482:1: (lv_ownedValue_2_0= ruleExpCS )
{
// InternalQVTbase.g:4482:1: (lv_ownedValue_2_0= ruleExpCS )
// InternalQVTbase.g:4483:3: lv_ownedValue_2_0= ruleExpCS
{
if ( state.backtracking==0 ) {
- newCompositeNode(grammarAccess.getMapLiteralPartCSAccess().getOwnedValueExpCSParserRuleCall_2_0());
+ newCompositeNode(grammarAccess.getMapLiteralPartCSAccess().getOwnedKeyExpCSParserRuleCall_2_0());
}
pushFollow(FollowSets000.FOLLOW_2);
- lv_ownedValue_2_0=ruleExpCS();
+ lv_ownedKey_2_0=ruleExpCS();
state._fsp--;
if (state.failed) return current;
@@ -13469,8 +13469,8 @@ public class InternalQVTbaseParser extends AbstractInternalAntlrParser {
}
set(
current,
- "ownedValue",
- lv_ownedValue_2_0,
+ "ownedKey",
+ lv_ownedKey_2_0,
"org.eclipse.ocl.xtext.essentialocl.EssentialOCL.ExpCS");
afterParserOrEnumRuleCall();
@@ -13386,38 +13386,38 @@ public class InternalQVTbaseParser extends AbstractInternalAntlrParser {
enterRule();
try {
- // InternalQVTbase.g:4458:28: ( ( ( (lv_ownedKey_0_0= ruleExpCS ) ) otherlv_1= '<-' ( (lv_ownedValue_2_0= ruleExpCS ) ) ) )
- // InternalQVTbase.g:4459:1: ( ( (lv_ownedKey_0_0= ruleExpCS ) ) otherlv_1= '<-' ( (lv_ownedValue_2_0= ruleExpCS ) ) )
+ // InternalQVTbase.g:4458:28: ( ( ( (lv_ownedValue_0_0= ruleExpCS ) ) otherlv_1= '<-' ( (lv_ownedKey_2_0= ruleExpCS ) ) ) )
+ // InternalQVTbase.g:4459:1: ( ( (lv_ownedValue_0_0= ruleExpCS ) ) otherlv_1= '<-' ( (lv_ownedKey_2_0= ruleExpCS ) ) )
{
@@ -13386,38 +13386,38 @@ public class InternalQVTbaseParser extends AbstractInternalAntlrParser {
{
- // InternalQVTbase.g:4459:1: ( ( (lv_ownedKey_0_0= ruleExpCS ) ) otherlv_1= '<-' ( (lv_ownedValue_2_0= ruleExpCS ) ) )
- // InternalQVTbase.g:4459:2: ( (lv_ownedKey_0_0= ruleExpCS ) ) otherlv_1= '<-' ( (lv_ownedValue_2_0= ruleExpCS ) )
+ // InternalQVTbase.g:4459:1: ( ( (lv_ownedValue_0_0= ruleExpCS ) ) otherlv_1= '<-' ( (lv_ownedKey_2_0= ruleExpCS ) ) )
+ // InternalQVTbase.g:4459:2: ( (lv_ownedValue_0_0= ruleExpCS ) ) otherlv_1= '<-' ( (lv_ownedKey_2_0= ruleExpCS ) )
{
@@ -13386,38 +13386,38 @@ public class InternalQVTbaseParser extends AbstractInternalAntlrParser {
{
- // InternalQVTbase.g:4459:2: ( (lv_ownedKey_0_0= ruleExpCS ) )
- // InternalQVTbase.g:4460:1: (lv_ownedKey_0_0= ruleExpCS )
+ // InternalQVTbase.g:4459:2: ( (lv_ownedValue_0_0= ruleExpCS ) )
+ // InternalQVTbase.g:4460:1: (lv_ownedValue_0_0= ruleExpCS )
{
@@ -13386,38 +13386,38 @@ public class InternalQVTbaseParser extends AbstractInternalAntlrParser {
{
- // InternalQVTbase.g:4460:1: (lv_ownedKey_0_0= ruleExpCS )
- // InternalQVTbase.g:4461:3: lv_ownedKey_0_0= ruleExpCS
+ // InternalQVTbase.g:4460:1: (lv_ownedValue_0_0= ruleExpCS )
+ // InternalQVTbase.g:4461:3: lv_ownedValue_0_0= ruleExpCS
{
if ( state.backtracking==0 ) {
@@ -13446,19 +13446,19 @@ public class InternalQVTbaseParser extends AbstractInternalAntlrParser {
newLeafNode(otherlv_1, grammarAccess.getMapLiteralPartCSAccess().getLessThanSignHyphenMinusKeyword_1());
}
- // InternalQVTbase.g:4481:1: ( (lv_ownedValue_2_0= ruleExpCS ) )
- // InternalQVTbase.g:4482:1: (lv_ownedValue_2_0= ruleExpCS )
+ // InternalQVTbase.g:4481:1: ( (lv_ownedKey_2_0= ruleExpCS ) )
+ // InternalQVTbase.g:4482:1: (lv_ownedKey_2_0= ruleExpCS )
{
@@ -13446,19 +13446,19 @@ public class InternalQVTbaseParser extends AbstractInternalAntlrParser {
{
- // InternalQVTbase.g:4482:1: (lv_ownedValue_2_0= ruleExpCS )
- // InternalQVTbase.g:4483:3: lv_ownedValue_2_0= ruleExpCS
+ // InternalQVTbase.g:4482:1: (lv_ownedKey_2_0= ruleExpCS )
+ // InternalQVTbase.g:4483:3: lv_ownedKey_2_0= ruleExpCS
{
if ( state.backtracking==0 ) {